@@ -3,7 +3,8 @@ CEOdataStartupMessage <- function()
   msg <- c(paste0("CEOdata version ", 
            utils::packageVersion("CEOdata")),
            "\nThis package needs a working Internet connection to effectively run.",
-           "\nPlease acknowledge the CEO in your publications.\nType \"vignette('using_CEOdata')\" or \"vignette('cheatsheet')\" for basic help.")
+           "\nPlease acknowledge the CEO in your publications.\nType \"vignette('using_CEOdata')\" or \"vignette('cheatsheet')\" for basic help.",
+           "\n\nThis package, by default, transforms the data gathered from the CEO\ninto pure-R factors. If you want to keep the SPSS labelled format\nyou can use 'raw = TRUE' when calling its functions.")
   return(msg)
 }
 
